#
# spec file for package python-nbval
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-nbval%{psuffix}
Version:        0.11.0
Release:        2.2
Summary:        A pytest plugin to validate Jupyter notebooks
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/computationalmodelling/nbval
Source:         https://files.pythonhosted.org/packages/source/n/nbval/nbval-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-coverage
Requires:       python-ipykernel
Requires:       python-jupyter-client
Requires:       python-nbformat
Requires:       python-pytest >= 7
Provides:       python-jupyter_nbval = %{version}
Obsoletes:      python-jupyter_nbval < %{version}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module nbdime}
BuildRequires:  %{python_module nbval = %{version}}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module sympy}
%endif
%if "%{python_flavor}" == "python3" || "%{?python_provides}"  == "python3"
Provides:       jupyter-nbval = %{version}
%endif
%python_subpackages

%description
The plugin adds functionality to py.test to recognise and collect
Jupyter notebooks. The intended purpose of the tests is to determine
whether execution of the stored inputs match the stored outputs of
the .ipynb file. Whilst also ensuring that the notebooks are running
without errors.

The tests were designed to ensure that Jupyter notebooks (especially
those for reference and documentation), are executing consistently.

Each cell is taken as a test, a cell that doesn't reproduce the
expected output will fail.

%prep
%autosetup -p1 -n nbval-%{version}
sed -i 's/\r$//' README.md

%if ! %{with test}
%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# see dodo.py for call signature
%{pytest tests/ --nbval \
                --nbval-current-env \
                --nbval-sanitize-with tests/sanitize_defaults.cfg \
                --ignore tests/ipynb-test-samples
}
%endif

%if ! %{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/nbval
%{python_sitelib}/nbval-%{version}.dist-info
%endif

%changelog
* Wed Sep 25 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.11.0
  * no release notes
  * pure maintenance
- Skip python39: no longer supported since ipython 8.19 (via
  ipykernel)
* Sun Jan 15 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.10.0
  * no release notes
- Drop nbval-filter-mpldeprecation.patch
- Drop nbval-sanitize-figure-size.patch
- Drop 0001-Make-tests-pass-with-ipykernel-6.0.0.patch
* Sat Aug 20 2022 Ben Greiner <code@bnavigator.de>
- Remove python36 skiptest code
- Add nbval-sanitize-figure-size.patch
  * gh#computationalmodelling/nbval#183
* Mon Nov 15 2021 Ben Greiner <code@bnavigator.de>
- Multibuild test flavor: avoid (possible) build cycle
* Sun Aug 29 2021 Ben Greiner <code@bnavigator.de>
- Add 0001-Make-tests-pass-with-ipykernel-6.0.0.patch from Arch
* Wed Apr 14 2021 Ben Greiner <code@bnavigator.de>
-  Add nbval-filter-mpldeprecation.patch for new Matplotlib 3.4
  deprecation warnings -- gh#computationalmodelling/nbval#167
* Fri Feb 26 2021 Ben Greiner <code@bnavigator.de>
- Don't test numpy and matplotlib with Python 3.6: There is no
  python36-numpy and python36-matplotlib in TW. (NEP 29)
* Thu Dec 17 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 0.9.6
  * fix compatibility with pytest >= 6 and python 3.8
- enable tests
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Provide the old jupyter package name only for the primary
  Python3 interpreter -- gh#openSUSE/python-rpm-macros#66
* Mon Feb 24 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.9.5
  * Add Python 3.8 to Appveyor
  * Allow Python nightly fail in Travis
  * Fix coverage for coverage.py >=5
  * Add Python 3.8 to Travis
* Wed Jan 15 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.9.4
  * Mark nbval as incompatible with coverage
  * Workaround for Python 3.7 on Travis no longer needed
  * Drop Python 2.7 testing on Windows again
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.9.3
  * Use a MULTILINE anchored regex when removing carriage returns
- Drop python2 support due to python-notebook dropping python2 support
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.9.2
  * Update latex tests' output
  * Do not compare widget views
  * Replace deprecated warning API
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 0.9.1
  * Only pass absolute config path if config file exists
  * Ignore .pytest_cache
  * Mark cells in generated notebook as run
  * Rerun sample notebook
  * Pass coverage config file by absolute path
  * Respect the --color=no option
  * Ensure test works on python 2
  * Optionally mark run cells with exc. count in tests
* Fri Apr 20 2018 toddrme2178@gmail.com
- Initial version
